;
; zcode700
; switch and front panel setup
; 01/10/2007


	

_testSw1	btfsc	sw1	; Skip next if sw1 down
	goto	_sw1Released	; else sw1 is up (released)
	bcf	flags2, sw1Last	; set flag to current sw1 state
	incfsz	sw1timer,F	; increment sw1Timer and skip next if it rollsover (>1 second)
	return
			; sw1 held for >1sec, exit from front panel setup
_sw1Long	movlw	.16	; load .16 (blank) into W
	movwf	digit1	; set all 3 digits to blank
	movwf	digit2
	movwf	digit3
	btfsc	flags, fpSave	; test state of fpSave flag
	goto	_startSave	; if set, save to EEPROM and reset
	movfw	myAddress	; if not, restore current settings for device address and bit rate
	movwf	eepromAddress
	movfw	savedBitRate
	movwf	eepromBitRate
	movfw	activeTmrEn
	movwf	eepromInactive
	bsf	flags2,exitFP	; set exitFP flag to indicate to calling code we are done
	return

			; 
_sw1Released	btfsc	flags2, sw1Last	; check flag for previous state of sw1
	return		; return if it was up
	bsf	flags2, sw1Last	; set sw1Last flag (sw1 is up)
		
	clrf	sw1timer	; reset sw1timer
	incf	fpState,F	; increment fpState
	movlw	-.4	; and test if it has reached 3
	addwf	fpState,W	
	skpnz		; skip if it hasn't
	clrf	fpState	; reset to 0 if it has

			; This code just sets up the 7-seg display with the current
			; value for the selected setting mode before any keys are pressed
	movfw	fpState	; fpState indicates which setting mode we're in
	bz	_dispAddr	; 0 for address
	addlw	-.1
	bz	_dispBit	; 1 for bit rate
	addlw	-.1
	bz	_dispTimer
	goto	_dispSave	; 3 for save yes/no
	



_testSw2	btfss	sw2	; Skip next if sw2 up (released)
	goto	_sw2Down	; otherwise do the sw2 down code
	movlw	.187	; 750mS long intial repeat delay
	movwf	sw2timer	; preload sw2timer ready for next time
	bsf	flags,sw2Last	; set sw2Last flag to indicate previous switch state
	return

_sw2Down	btfsc	flags,sw2Last	; was sw2 down last time through this code?
	goto	_Sw2Edge	; No then sw2 has just been pressed 
	decfsz	sw2timer,F	; decrement sw2Timer, skip if reached 0
	return
	movlw	.12	; 256ms hold down repeat delay
	movwf	sw2timer	; reload sw2Timer for fast repeat
		
			; Only do key repeat when in address mode.
	movf	fpState,F	; test if fpState == 0
	skpz		; skip next if true
	return		; else return

_Sw2Edge	bcf	flags,sw2Last	; clear sw2Last flag to indicate previous state
	movfw	fpState	; load fpState and run code for current mode
	bz	_doSwAddress	; 
	addlw	-.1
	bz	_doSwBitRate
	addlw	-.1
	bz	_doToggleTmr
	
; --------------------------
_doSwSave	movlw	(1<<fpSave)	; toggle fpsave flag
	xorwf	flags,F

_dispSave	btfss	flags, fpSave	; test fpsave flag and setup 7seg data
	goto	_fpNoSave
	movlw	.19	;Y
	movwf	digit3
	movlw	.14	;E
	movwf	digit2
	movlw	.5	;5
	movwf	digit1
	return

_fpNoSave	movlw	.17	;n
	movwf	digit3
	movlw	.18	;o
	movwf	digit2
	movlw	.16	; [blank]
	movwf	digit1
	return


; --------------------------
_doToggleTmr	clrw
	movf	eepromInactive,F	; 
	skpnz
	movlw	0x01
	movwf	eepromInactive	; 

_dispTimer	movf	eepromInactive,F; test 
	bz	_TimerOff
	movlw	.16	; [blank]
	movwf	digit3
	movlw	.18	; o
	movwf	digit2
	movlw	.17	; n
	movwf	digit1
	return

_TimerOff	movlw	.0	; 0
	movwf	digit3
	movlw	.15	; F
	movwf	digit2
	movlw	.15	; F
	movwf	digit1
	return








; --------------------------
_doSwAddress	incf 	eepromAddress,F	; increment eepromAddress	
	movlw	-.128		; test if reached 128
	addwf	eepromAddress,W
	skpnz
	clrf	eepromAddress		; reset to 0 if it was

_dispAddr	movfw   	eepromAddress 		; get eepromAddress in W
	call	_bin2bcd		; convert to binary to BCD
	call	_bcdTo7Seg		; convert BCD value to 7seg drive data
	return



; --------------------------
_doSwBitRate	incf	eepromBitRate,F		; increment eepromBitRate
	movlw	-.5		; test if reached 5
	addwf	eepromBitRate,W
	skpnz
	clrf	eepromBitRate		; reset to 0 if it has

_dispBit	movfw   	eepromBitRate		; load eepromBitRate into W
	bz	_br1200		; test W 
	addlw	-.1
	bz	_br2400
	addlw	-.1
	bz	_br9600
	addlw	-.1
	bz	_br19200
				; If it wasn't 0 to 3 it must be 4
	movlw	.3		; 3
	movwf	digit2
	movlw	.8		; 8
	movwf	digit1
	
_brBlank3	movlw	.16		; set MSD to blank for all 
	movwf	digit3
	return

_br1200	movlw	.1 + .128		; 1 with decimal point
	movwf	digit2
	movlw	.2 		; 2
	movwf	digit1
	goto	_brBlank3

_br2400	movlw	.2 + .128		; 2 with decimal point
	movwf	digit2	
	movlw	.4 		; 4
	movwf	digit1
	goto	_brBlank3

_br9600	movlw	.9 + .128		; 9 with decimal point
	movwf	digit2
	movlw	.6		; 6
	movwf	digit1
	goto	_brBlank3

_br19200	movlw	.1		; 1
	movwf	digit2
	movlw	.9		; 9
	movwf	digit1
	goto	_brBlank3